==> owncloud-8.1.0p2.tgz: owncloud/apps/files/l10n/th_TH.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "ไม่สามารถใช้พื้นที่จัดเก็บข้อมูลได้",
    "Storage invalid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Unknown error" : "ข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "Could not move %s - File with this name already exists" : "ไม่สามารถย้าย %s ได้ - ไฟล์ที่ใช้ชื่อนี้มีอยู่แล้ว",
    "Could not move %s" : "ไม่สามารถย้าย %s ได้",
    "Permission denied" : "ไม่อนุญาต",
    "The target folder has been moved or deleted." : "โฟลเดอร์ปลายทางถูกย้ายหรือลบ",
    "The name %s is already used in the folder %s. Please choose a different name." : "ชื่อ %s ถูกใช้ไปแล้วในโฟลเดอร์ %s โปรดเลือกชื่ออื่นที่แตกต่างกัน",
    "Error when creating the file" : "เกิดข้อผิดพลาดเมื่อมีการสร้างไฟล์",
    "Error when creating the folder" : "เกิดข้อผิดพลาดเมื่อมีการสร้างโฟลเดอร์",
    "Unable to set upload directory." : "ไม่สามารถตั้งค่าอัพโหลดไดเรกทอรี",
    "Invalid Token" : "โทเค็นไม่ถูกต้อง",
    "No file was uploaded. Unknown error" : "ยังไม่มีไฟล์ใดที่ถูกอัพโหลด เกิดข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "There is no error, the file uploaded with success" : "ไม่พบข้อผิดพลาดใดๆ, ไฟล์ถูกอัพโหลดเรียบร้อยแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "ขนาดไฟล์ที่อัพโหลดมีขนาดเกิน upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัพโหลดมีขนาดไฟล์ใหญ่เกินจำนวนที่กำหนดไว้ในคำสั่ง MAX_FILE_SIZE ที่ถูกระบุไว้ในรูปแบบของ HTML",
    "The uploaded file was only partially uploaded" : "ไฟล์ถูกอัพโหลดได้เพียงบางส่วนเท่านั้น",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัพโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
    "Failed to write to disk" : "เขียนข้อมูลลงแผ่นดิสก์ล้มเหลว",
    "Not enough storage available" : "เหลือพื้นที่ไม่เพียงสำหรับใช้งาน",
    "Upload failed. Could not find uploaded file" : "อัปโหลดล้มเหลว ไม่สามารถหาไฟล์ที่จะอัพโหลด",
    "Upload failed. Could not get file info." : "อัพโหลดล้มเหลว ไม่สามารถรับข้อมูลไฟล์",
    "Invalid directory." : "ไดเร็กทอรี่ไม่ถูกต้อง",
    "Files" : "ไฟล์",
    "All files" : "ไฟล์ทั้งหมด",
    "Favorites" : "รายการโปรด",
    "Home" : "บ้าน",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ไม่สามารถอัพโหลด {filename} มันเป็นไดเรกทอรีหรือมี 0 ไบต์",
    "Total file size {size1} exceeds upload limit {size2}" : "ขนาดไฟล์ {size1} ทั้งหมดเกินขีดจำกัด ของการอัพโหลด {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "พื้นที่ว่างไม่เพียงพอคุณจะอัพโหลด {size1} แต่มีพืนที่แค่ {size2}",
    "Upload cancelled." : "การอัพโหลดถูกยกเลิก",
    "Could not get result from server." : "ไม่สามารถรับผลลัพธ์จากเซิร์ฟเวอร์",
    "File upload is in progress. Leaving the page now will cancel the upload." : "การอัพโหลดไฟล์กำลังอยู่ในระหว่างดำเนินการ การออกจากหน้าเว็บนี้จะทำให้การอัพโหลดถูกยกเลิก",
    "{new_name} already exists" : "{new_name} มีอยู่แล้วในระบบ",
    "Could not create file" : "ไม่สามารถสร้างไฟล์",
    "Could not create folder" : "ไม่สามารถสร้างโฟลเดอร์",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Disconnect storage" : "ยกเลิกการเชื่อมต่อการจัดเก็บข้อมูล",
    "Unshare" : "ยกเลิกการแชร์",
    "No permission to delete" : "ไม่อนุญาตให้ลบ",
    "Download" : "ดาวน์โหลด",
    "Select" : "เลือก",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Unable to determine date" : "ไม่สามารถกำหนดวัน",
    "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
    "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
    "Error moving file." : "ข้อผิดพลาดในการเคลื่อนย้ายไฟล์",
    "Error moving file" : "ข้อผิดพลาดในการเคลื่อนย้ายไฟล์",
    "Error" : "ข้อผิดพลาด",
    "Could not rename file" : "ไม่สามารถเปลี่ยนชื่อไฟล์",
    "Error deleting file." : "เกิดข้อผิดพลาดในการลบไฟล์",
    "No entries in this folder match '{filter}'" : "ไม่มีรายการในโฟลเดอร์นี้ที่ตรงกับ '{filter}'",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขแล้ว",
    "_%n folder_::_%n folders_" : ["%n โฟลเดอร์"],
    "_%n file_::_%n files_" : ["%n ไฟล์"],
    "You don’t have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัพโหลดหรือสร้างไฟล์ที่นี่",
    "_Uploading %n file_::_Uploading %n files_" : ["อัพโหลด %n ไฟล์"],
    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของ {owner} เต็มแล้ว  ไฟล์ไม่สามารถอัพเดทหรือผสานข้อมูลได้อีก!",
    "Your storage is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัพเดทหรือผสานข้อมูลได้อีก!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของ {owner} ใกล้เต็มแล้ว\nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว \nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ตรงกับ '{filter}'"],
    "{dirs} and {files}" : "{dirs} และ {files}",
    "Favorited" : "รายการโปรด",
    "Favorite" : "รายการโปรด",
    "An error occurred while trying to update the tags" : "เกิดข้อผิดพลาดขณะที่พยายามจะปรับปรุงแท็ก",
    "A new file or folder has been <strong>created</strong>" : "มีไฟล์ใหม่หรือโฟลเดอร์ได้ถูก <strong>สร้างขึ้น!</strong>",
    "A file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ได้ถูก <strong>เปลี่ยน!</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "จำกัดการแจ้งเตือนเกี่ยวกับการสร้างและการเปลี่ยนแปลงของคุณ <strong>ไฟล์ที่ชื่นชอบ</strong> <em>(สตรีมเท่านั้น)</em>",
    "A file or folder has been <strong>deleted</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>ลบ</strong>",
    "A file or folder has been <strong>restored</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>กู้คืน</strong>",
    "You created %1$s" : "คุณสร้าง %1$s",
    "%2$s created %1$s" : "%2$s สร้าง %1$s",
    "%1$s was created in a public folder" : "%1$s ถูกสร้างขึ้นในโฟลเดอร์สาธารณะ",
    "You changed %1$s" : "คุณทำการเปลี่ยนแปลง %1$s",
    "%2$s changed %1$s" : "%2$s ได้เปลี่ยนแปลง %1$s",
    "You deleted %1$s" : "คุณลบ %1$s ออก",
    "%2$s deleted %1$s" : "%2$s ลบ %1$s ออก",
    "You restored %1$s" : "คุณกู้คืน %1$s",
    "%2$s restored %1$s" : "%2$s ได้กู้คืน %1$s",
    "%s could not be renamed as it has been deleted" : "%s ไม่สามารถเปลี่ยนชื่อเนื่องจากถูกลบไปแล้ว",
    "%s could not be renamed" : "%s ไม่สามารถเปลี่ยนชื่อ",
    "Upload (max. %s)" : "อัพโหลด (สูงสุด %s)",
    "File handling" : "การจัดการไฟล์",
    "Maximum upload size" : "ขนาดไฟล์สูงสุดที่อัพโหลดได้",
    "max. possible: " : "จำนวนสูงสุดที่สามารถทำได้: ",
    "Save" : "บันทึก",
    "Can not be edited from here due to insufficient permissions." : "ไม่สามารถแก้ไขได้จากที่นี่เนื่องจากสิทธิ์ไม่เพียงพอ",
    "Settings" : "ตั้งค่า",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "ใช้ที่อยู่นี้เพื่อ <a href=\"%s\" target=\"_blank\">เข้าถึงไฟล์ของคุณผ่าน WebDAV</a>",
    "New" : "ใหม่",
    "New text file" : "ไฟล์ข้อความใหม่",
    "Text file" : "ไฟล์ข้อความ",
    "New folder" : "โฟลเดอร์ใหม่",
    "Folder" : "แฟ้มเอกสาร",
    "Upload" : "อัพโหลด",
    "Cancel upload" : "ยกเลิกการอัพโหลด",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "Upload some content or sync with your devices!" : "อัพโหลดเนื้อหาบางส่วนหรือผสานข้อมูลกับอุปกรณ์ของคุณ! อีกครั้ง",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Select all" : "เลือกทั้งหมด",
    "Upload too large" : "ไฟล์ที่อัพโหลดมีขนาดใหญ่เกินไป",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัพโหลดมีขนาดเกินกว่าขนาดสูงสุดที่กำหนดไว้ให้อัพโหลดได้สำหรับเซิร์ฟเวอร์นี้",
    "Files are being scanned, please wait." : "ไฟล์กำลังอยู่ระหว่างการสแกน, กรุณารอสักครู่.",
    "Currently scanning" : "ปัจจุบันกำลังสแกน",
    "No favorites" : "ไม่มีรายการโปรด",
    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณทำเครื่องหมายเป็นรายการโปรดจะปรากฏขึ้นที่นี่"
},
"nplurals=1; plural=0;");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files/l10n/th_TH.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "ไม่สามารถใช้พื้นที่จัดเก็บข้อมูลได้",
    "Storage invalid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Unknown error" : "ข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "Could not move %s - File with this name already exists" : "ไม่สามารถย้าย %s ได้ - ไฟล์ที่ใช้ชื่อนี้มีอยู่แล้ว",
    "Could not move %s" : "ไม่สามารถย้าย %s ได้",
    "Permission denied" : "ไม่อนุญาต",
    "The target folder has been moved or deleted." : "โฟลเดอร์ปลายทางถูกย้ายหรือลบ",
    "The name %s is already used in the folder %s. Please choose a different name." : "ชื่อ %s ถูกใช้ไปแล้วในโฟลเดอร์ %s โปรดเลือกชื่ออื่นที่แตกต่างกัน",
    "Error when creating the file" : "เกิดข้อผิดพลาดเมื่อมีการสร้างไฟล์",
    "Error when creating the folder" : "เกิดข้อผิดพลาดเมื่อมีการสร้างโฟลเดอร์",
    "Unable to set upload directory." : "ไม่สามารถตั้งค่าอัพโหลดไดเรกทอรี",
    "Invalid Token" : "โทเค็นไม่ถูกต้อง",
    "No file was uploaded. Unknown error" : "ยังไม่มีไฟล์ใดที่ถูกอัพโหลด เกิดข้อผิดพลาดที่ไม่ทราบสาเหตุ",
    "There is no error, the file uploaded with success" : "ไม่พบข้อผิดพลาดใดๆ, ไฟล์ถูกอัพโหลดเรียบร้อยแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "ขนาดไฟล์ที่อัพโหลดมีขนาดเกิน upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัพโหลดมีขนาดไฟล์ใหญ่เกินจำนวนที่กำหนดไว้ในคำสั่ง MAX_FILE_SIZE ที่ถูกระบุไว้ในรูปแบบของ HTML",
    "The uploaded file was only partially uploaded" : "ไฟล์ถูกอัพโหลดได้เพียงบางส่วนเท่านั้น",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัพโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
    "Failed to write to disk" : "เขียนข้อมูลลงแผ่นดิสก์ล้มเหลว",
    "Not enough storage available" : "เหลือพื้นที่ไม่เพียงสำหรับใช้งาน",
    "Upload failed. Could not find uploaded file" : "อัพโหลดล้มเหลว ไม่สามารถหาไฟล์ที่จะอัพโหลด",
    "Upload failed. Could not get file info." : "อัพโหลดล้มเหลว ไม่สามารถรับข้อมูลไฟล์",
    "Invalid directory." : "ไดเร็กทอรี่ไม่ถูกต้อง",
    "Files" : "ไฟล์",
    "All files" : "ไฟล์ทั้งหมด",
    "Favorites" : "รายการโปรด",
    "Home" : "บ้าน",
    "Close" : "ปิด",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ไม่สามารถอัพโหลด {filename} มันเป็นไดเรกทอรีหรือมี 0 ไบต์",
    "Total file size {size1} exceeds upload limit {size2}" : "ขนาดไฟล์ {size1} ทั้งหมดเกินขีดจำกัด ของการอัพโหลด {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "พื้นที่ว่างไม่เพียงพอคุณจะอัพโหลด {size1} แต่มีพืนที่แค่ {size2}",
    "Upload cancelled." : "การอัพโหลดถูกยกเลิก",
    "Could not get result from server." : "ไม่สามารถรับผลลัพธ์จากเซิร์ฟเวอร์",
    "File upload is in progress. Leaving the page now will cancel the upload." : "การอัพโหลดไฟล์กำลังอยู่ในระหว่างดำเนินการ การออกจากหน้าเว็บนี้จะทำให้การอัพโหลดถูกยกเลิก",
    "Actions" : "การกระทำ",
    "Download" : "ดาวน์โหลด",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Details" : "รายละเอียด",
    "Select" : "เลือก",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Unable to determine date" : "ไม่สามารถกำหนดวัน",
    "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
    "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
    "Error moving file." : "ข้อผิดพลาดในการเคลื่อนย้ายไฟล์",
    "Error moving file" : "ข้อผิดพลาดในการเคลื่อนย้ายไฟล์",
    "Error" : "ข้อผิดพลาด",
    "{new_name} already exists" : "{new_name} มีอยู่แล้วในระบบ",
    "Could not rename file" : "ไม่สามารถเปลี่ยนชื่อไฟล์",
    "Could not create file" : "ไม่สามารถสร้างไฟล์",
    "Could not create folder" : "ไม่สามารถสร้างโฟลเดอร์",
    "Error deleting file." : "เกิดข้อผิดพลาดในการลบไฟล์",
    "No entries in this folder match '{filter}'" : "ไม่มีรายการในโฟลเดอร์นี้ที่ตรงกับ '{filter}'",
    "Name" : "ชื่อ",
    "Size" : "ขนาด",
    "Modified" : "แก้ไขแล้ว",
    "_%n folder_::_%n folders_" : ["%n โฟลเดอร์"],
    "_%n file_::_%n files_" : ["%n ไฟล์"],
    "{dirs} and {files}" : "{dirs} และ {files}",
    "You don’t have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัพโหลดหรือสร้างไฟล์ที่นี่",
    "_Uploading %n file_::_Uploading %n files_" : ["อัพโหลด %n ไฟล์"],
    "New" : "ใหม่",
    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของ {owner} เต็มแล้ว  ไฟล์ไม่สามารถอัพเดทหรือประสานข้อมูลได้อีก!",
    "Your storage is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัพเดทหรือประสานข้อมูลได้อีก!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของ {owner} ใกล้เต็มแล้ว\nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว \nใช้พื้นที่ไปแล้ว: ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["ตรงกับ '{filter}'"],
    "Path" : "เส้นทาง",
    "_%n byte_::_%n bytes_" : ["%n ไบต์"],
    "Favorited" : "รายการโปรด",
    "Favorite" : "รายการโปรด",
    "{newname} already exists" : "{newname} ถูกใช้ไปแล้ว",
    "Upload" : "อัพโหลด",
    "Text file" : "ไฟล์ข้อความ",
    "New text file.txt" : "ไฟล์ข้อความใหม่ .txt",
    "Folder" : "แฟ้มเอกสาร",
    "New folder" : "โฟลเดอร์ใหม่",
    "An error occurred while trying to update the tags" : "เกิดข้อผิดพลาดขณะที่พยายามจะปรับปรุงแท็ก",
    "A new file or folder has been <strong>created</strong>" : "มีไฟล์ใหม่หรือโฟลเดอร์ได้ถูก <strong>สร้างขึ้น!</strong>",
    "A file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ได้ถูก <strong>เปลี่ยน!</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "จำกัดการแจ้งเตือนเกี่ยวกับการสร้างและการเปลี่ยนแปลงของคุณ <strong>ไฟล์ที่ชื่นชอบ</strong> <em>(สตรีมเท่านั้น)</em>",
    "A file or folder has been <strong>deleted</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>ลบ</strong>",
    "A file or folder has been <strong>restored</strong>" : "ไฟล์หรือโฟลเดอร์ถูก <strong>กู้คืน</strong>",
    "You created %1$s" : "คุณสร้าง %1$s",
    "%2$s created %1$s" : "%2$s สร้าง %1$s",
    "%1$s was created in a public folder" : "%1$s ถูกสร้างขึ้นในโฟลเดอร์สาธารณะ",
    "You changed %1$s" : "คุณทำการเปลี่ยนแปลง %1$s",
    "%2$s changed %1$s" : "%2$s ได้เปลี่ยนแปลง %1$s",
    "You deleted %1$s" : "คุณลบ %1$s ออก",
    "%2$s deleted %1$s" : "%2$s ลบ %1$s ออก",
    "You restored %1$s" : "คุณกู้คืน %1$s",
    "%2$s restored %1$s" : "%2$s ได้กู้คืน %1$s",
    "Changed by %2$s" : "เปลี่ยนแปลงโดย %2$s",
    "Deleted by %2$s" : "ลบโดย %2$s",
    "Restored by %2$s" : "กู้คืนโดย %2$s",
    "%s could not be renamed as it has been deleted" : "%s ไม่สามารถเปลี่ยนชื่อเนื่องจากถูกลบไปแล้ว",
    "%s could not be renamed" : "%s ไม่สามารถเปลี่ยนชื่อ",
    "Upload (max. %s)" : "อัพโหลด (สูงสุด %s)",
    "File handling" : "การจัดการไฟล์",
    "Maximum upload size" : "ขนาดไฟล์สูงสุดที่อัพโหลดได้",
    "max. possible: " : "จำนวนสูงสุดที่สามารถทำได้: ",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "ด้วยค่า PHP-FPM นี้อาจใช้เวลาถึง 5 นาที จะมีผลหลังจากการบันทึก",
    "Save" : "บันทึก",
    "Can not be edited from here due to insufficient permissions." : "ไม่สามารถแก้ไขได้จากที่นี่เนื่องจากสิทธิ์ไม่เพียงพอ",
    "Settings" : "ตั้งค่า",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "ใช้ที่อยู่นี้เพื่อ <a href=\"%s\" target=\"_blank\">เข้าถึงไฟล์ของคุณผ่าน WebDAV</a>",
    "Cancel upload" : "ยกเลิกการอัพโหลด",
    "No files in here" : "ไม่มีไฟล์ที่นี่",
    "Upload some content or sync with your devices!" : "อัพโหลดเนื้อหาบางส่วนหรือประสานข้อมูลกับอุปกรณ์ของคุณ! อีกครั้ง",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Select all" : "เลือกทั้งหมด",
    "Upload too large" : "ไฟล์ที่อัพโหลดมีขนาดใหญ่เกินไป",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัพโหลดมีขนาดเกินกว่าขนาดสูงสุดที่กำหนดไว้ให้อัพโหลดได้สำหรับเซิร์ฟเวอร์นี้",
    "Files are being scanned, please wait." : "ไฟล์กำลังอยู่ระหว่างการสแกน, กรุณารอสักครู่.",
    "Currently scanning" : "ปัจจุบันกำลังสแกน",
    "No favorites" : "ไม่มีรายการโปรด",
    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณทำเครื่องหมายเป็นรายการโปรดจะปรากฏขึ้นที่นี่"
},
"nplurals=1; plural=0;");
